@@ -41,7 +41,7 @@ from .images import (
     _raise_on_error_chunk,
     _try_parse_image_progress_step,
 )
-from .parser import Parser, Volume
+from .parser import Parser, SecretFile, Volume
 from .parsing_utils import LocalImage, RemoteImage, _as_repo_str, _is_in_neuro_registry
 from .server_cfg import Preset
 from .url_utils import normalize_secret_uri, normalize_storage_path_uri
@@ -71,8 +71,8 @@ class JobStatus(str, enum.Enum):
     possibly waiting for) sufficient amount of resources, pulling an image
     from a registry etc.
     RUNNING: a job is being run.
-    SUCCEEDED: a job terminated with the 0 exit code or a running job was
-    manually terminated/deleted.
+    SUCCEEDED: a job terminated with the 0 exit code.
+    CANCELLED: a running job was manually terminated/deleted.
     FAILED: a job terminated with a non-0 exit code.
     """
 
@@ -80,6 +80,7 @@ class JobStatus(str, enum.Enum):
     RUNNING = "running"
     SUCCEEDED = "succeeded"
     FAILED = "failed"
+    CANCELLED = "cancelled"
     UNKNOWN = "unknown"  # invalid status code, a default value is status is not sent
 
 
@@ -89,12 +90,6 @@ class HTTPPort:
     requires_auth: bool = True
 
 
-@dataclass(frozen=True)
-class SecretFile:
-    secret_uri: URL
-    container_path: str
-
-
 @dataclass(frozen=True)
 class Container:
     image: RemoteImage
@@ -288,8 +283,10 @@ class Jobs(metaclass=NoPublicConstructor):
         ) as resp:
             if resp.headers.get("Content-Type", "").startswith("application/x-ndjson"):
                 async for line in resp.content:
-                    j = json.loads(line)
-                    yield _job_description_from_api(j, self._parse)
+                    server_message = json.loads(line)
+                    if "error" in server_message:
+                        raise Exception(server_message["error"])
+                    yield _job_description_from_api(server_message, self._parse)
             else:
                 ret = await resp.json()
                 for j in ret["jobs"]:
