@@ -1,14 +1,13 @@
 import asyncio
 import contextlib
 import logging
-import os
 import re
 import shlex
 import sys
 import uuid
 import webbrowser
 from datetime import datetime, timedelta
-from typing import Dict, Iterator, List, Optional, Sequence, Set, Tuple
+from typing import List, Optional, Sequence, Set, Tuple
 
 import async_timeout
 import click
@@ -25,7 +24,6 @@ from neuromation.api import (
     JobStatus,
     RemoteImage,
     Resources,
-    SecretFile,
     Volume,
 )
 from neuromation.cli.formatters.images import DockerImageProgress
@@ -73,7 +71,6 @@ from .utils import (
     group,
     option,
     pager_maybe,
-    parse_secret_resource,
     resolve_job,
     volume_to_verbose_str,
 )
@@ -82,11 +79,6 @@ from .utils import (
 log = logging.getLogger(__name__)
 
 STORAGE_MOUNTPOINT = "/var/storage"
-ROOT_MOUNTPOINT = "/var/neuro"
-
-NEUROMATION_ROOT_ENV_VAR = "NEUROMATION_ROOT"
-NEUROMATION_HOME_ENV_VAR = "NEUROMATION_HOME"
-RESERVED_ENV_VARS = {NEUROMATION_ROOT_ENV_VAR, NEUROMATION_HOME_ENV_VAR}
 
 DEFAULT_JOB_LIFE_SPAN = "1d"
 REGEX_TIME_DELTA = re.compile(
@@ -107,48 +99,6 @@ TTY_OPT = option(
 )
 
 
-def _get_neuro_mountpoint(username: str) -> str:
-    return f"{ROOT_MOUNTPOINT}/{username}"
-
-
-def _read_lines(env_file: str) -> Iterator[str]:
-    with open(env_file, encoding="utf-8-sig") as ef:
-        lines = ef.read().splitlines()
-    for line in lines:
-        line = line.lstrip()
-        if line and not line.startswith("#"):
-            yield line
-
-
-def build_env(env: Sequence[str], env_file: Optional[str]) -> Dict[str, str]:
-    if env_file:
-        env = [*_read_lines(env_file), *env]
-
-    env_dict = {}
-    for line in env:
-        splitted = line.split("=", 1)
-        name = splitted[0]
-        if len(splitted) == 1:
-            val = os.environ.get(splitted[0], "")
-        else:
-            val = splitted[1]
-        if name in RESERVED_ENV_VARS:
-            raise click.UsageError(
-                f"Unable to re-define system-reserved environment variable: {name}"
-            )
-        env_dict[name] = val
-    return env_dict
-
-
-def _extract_secret_env(env_dict: Dict[str, str], root: Root) -> Dict[str, URL]:
-    secret_env_dict = {}
-    for name, val in env_dict.copy().items():
-        if val.startswith("secret:"):
-            secret_env_dict[name] = parse_secret_resource(val, root)
-            del env_dict[name]
-    return secret_env_dict
-
-
 @group()
 def job() -> None:
     """
@@ -286,6 +236,7 @@ def job() -> None:
 @option(
     "--env-file",
     type=click.Path(exists=True),
+    multiple=True,
     help="File with environment variables to pass",
     secure=True,
 )
@@ -350,7 +301,7 @@ async def submit(
     working_dir: Optional[str],
     volume: Sequence[str],
     env: Sequence[str],
-    env_file: Optional[str],
+    env_file: Sequence[str],
     restart: str,
     life_span: Optional[str],
     port_forward: List[Tuple[int, int]],
@@ -544,6 +495,7 @@ async def logs(root: Root, job: str) -> None:
             JobStatus.PENDING,
             JobStatus.RUNNING,
             JobStatus.SUCCEEDED,
+            JobStatus.CANCELLED,
             JobStatus.FAILED,
         },
     )
@@ -571,6 +523,7 @@ async def attach(root: Root, job: str, port_forward: List[Tuple[int, int]]) -> N
             JobStatus.PENDING,
             JobStatus.RUNNING,
             JobStatus.SUCCEEDED,
+            JobStatus.CANCELLED,
             JobStatus.FAILED,
         },
     )
@@ -736,6 +689,7 @@ async def status(root: Root, job: str, full_uri: bool) -> None:
             JobStatus.PENDING,
             JobStatus.RUNNING,
             JobStatus.SUCCEEDED,
+            JobStatus.CANCELLED,
             JobStatus.FAILED,
         },
     )
@@ -822,6 +776,7 @@ async def save(root: Root, job: str, image: RemoteImage) -> None:
             JobStatus.PENDING,
             JobStatus.RUNNING,
             JobStatus.SUCCEEDED,
+            JobStatus.CANCELLED,
             JobStatus.FAILED,
         },
     )
@@ -973,6 +928,7 @@ async def kill(root: Root, jobs: Sequence[str]) -> None:
 @option(
     "--env-file",
     type=click.Path(exists=True),
+    multiple=True,
     help="File with environment variables to pass",
     secure=True,
 )
@@ -1043,7 +999,7 @@ async def run(
     workdir: Optional[str],
     volume: Sequence[str],
     env: Sequence[str],
-    env_file: Optional[str],
+    env_file: Sequence[str],
     restart: str,
     life_span: Optional[str],
     preemptible: Optional[bool],
@@ -1159,7 +1115,7 @@ async def run_job(
     working_dir: Optional[str],
     volume: Sequence[str],
     env: Sequence[str],
-    env_file: Optional[str],
+    env_file: Sequence[str],
     restart: str,
     life_span: Optional[str],
     port_forward: List[Tuple[int, int]],
@@ -1202,8 +1158,7 @@ async def run_job(
         job_schedule_timeout = _parse_timedelta(schedule_timeout).total_seconds()
     log.debug(f"Job schedule timeout: {job_schedule_timeout}")
 
-    env_dict = build_env(env, env_file)
-    secret_env_dict = _extract_secret_env(env_dict, root)
+    env_dict, secret_env_dict = root.client.parse.env(env, env_file)
     real_cmd = _parse_cmd(cmd)
 
     log.debug(f'entrypoint="{entrypoint}"')
@@ -1225,10 +1180,8 @@ async def run_job(
         tpu_type=tpu_type,
         tpu_software_version=tpu_software_version,
     )
-    input_secret_files = {vol for vol in volume if vol.startswith("secret:")}
-    input_volumes = set(volume) - input_secret_files
-    secret_files = await _build_secret_files(root, input_secret_files)
-    volumes = await _build_volumes(root, input_volumes, env_dict)
+
+    volumes, secret_files = root.client.parse.volumes(volume)
 
     if pass_config:
         env_name = NEURO_STEAL_CONFIG
@@ -1236,7 +1189,7 @@ async def run_job(
             raise ValueError(f"{env_name} is already set to {env_dict[env_name]}")
         env_var, secret_volume = await upload_and_map_config(root)
         env_dict[NEURO_STEAL_CONFIG] = env_var
-        volumes.add(secret_volume)
+        volumes.append(secret_volume)
 
     if volumes:
         log.info(
@@ -1297,60 +1250,6 @@ def _parse_cmd(cmd: Sequence[str]) -> str:
     return real_cmd
 
 
-async def _build_volumes(
-    root: Root, input_volumes: Set[str], env_dict: Dict[str, str]
-) -> Set[Volume]:
-    cluster_name = root.client.cluster_name
-    volumes: Set[Volume] = set()
-
-    if "ALL" in input_volumes:
-        if len(input_volumes) > 1:
-            raise click.UsageError(
-                f"Cannot use `--volume=ALL` together with other `--volume` options"
-            )
-        available = await root.client.users.get_acl(
-            root.client.username, scheme="storage"
-        )
-        for perm in available:
-            if perm.uri.host == cluster_name:
-                path = perm.uri.path
-                assert path[0] == "/"
-                volumes.add(
-                    Volume(
-                        storage_uri=perm.uri,
-                        container_path=f"{ROOT_MOUNTPOINT}{path}",
-                        read_only=perm.action not in ("write", "manage"),
-                    )
-                )
-        neuro_mountpoint = _get_neuro_mountpoint(root.client.username)
-        env_dict[NEUROMATION_HOME_ENV_VAR] = neuro_mountpoint
-        env_dict[NEUROMATION_ROOT_ENV_VAR] = ROOT_MOUNTPOINT
-        if not root.quiet:
-            click.echo(
-                "Storage mountpoints will be available as the environment variables:\n"
-                f"  {NEUROMATION_ROOT_ENV_VAR}={ROOT_MOUNTPOINT}\n"
-                f"  {NEUROMATION_HOME_ENV_VAR}={neuro_mountpoint}"
-            )
-    else:
-        if "HOME" in input_volumes:
-            raise ValueError("--volume=HOME no longer supported")
-        for vol in input_volumes:
-            volumes.add(root.client.parse.volume(vol))
-    return volumes
-
-
-async def _build_secret_files(root: Root, input_volumes: Set[str]) -> Set[SecretFile]:
-    secret_files: Set[SecretFile] = set()
-    for volume in input_volumes:
-        parts = volume.split(":")
-        if len(parts) != 3:
-            raise ValueError(f"Invalid secret file specification '{volume}'")
-        container_path = parts.pop()
-        secret_uri = parse_secret_resource(":".join(parts), root)
-        secret_files.add(SecretFile(secret_uri, container_path))
-    return secret_files
-
-
 async def upload_and_map_config(root: Root) -> Tuple[str, Volume]:
 
     # store the Neuro CLI config on the storage under some random path
