@@ -15,8 +15,8 @@ from aiodocker.exceptions import DockerError
 from click.exceptions import Abort as ClickAbort, Exit as ClickExit
 
 import neuromation
+import neuromation.api.errors
 from neuromation.api import CONFIG_ENV_NAME, DEFAULT_CONFIG_PATH, ConfigError
-from neuromation.cli.root import Root
 
 from . import (
     admin,
@@ -26,6 +26,7 @@ from . import (
     image,
     job,
     project,
+    secrets,
     share,
     storage,
 )
@@ -42,6 +43,7 @@ from .const import (
     EX_TIMEOUT,
 )
 from .log_formatter import ConsoleHandler, ConsoleWarningFormatter
+from .root import Root
 from .topics import topics
 from .tty_utils import enable_ansi
 from .utils import (
@@ -246,7 +248,10 @@ class MainGroup(Group):
         groups: List[Tuple[str, click.MultiCommand]] = []
         topics: List[Tuple[str, click.Command]] = []
         if self.topics is not None:
-            topics = list(self.topics.commands.items())
+            topics = [
+                (name, self.topics.get_command(ctx, name))
+                for name in self.topics.list_commands(ctx)
+            ]
 
         for subcommand in self.list_commands(ctx):
             cmd = self.get_command(ctx, subcommand)
@@ -478,6 +483,8 @@ cli.add_command(config.config)
 cli.add_command(completion.completion)
 cli.add_command(share.acl)
 cli.add_command(blob_storage.blob_storage)
+cli.add_command(blob_storage.blob_storage)
+cli.add_command(secrets.secret)
 
 cli.add_command(DeprecatedGroup(storage.storage, name="store", hidden=True))
 
@@ -526,26 +533,26 @@ def main(args: Optional[List[str]] = None) -> None:
         LOG_ERROR("Timeout")
         sys.exit(EX_TIMEOUT)
 
-    except neuromation.api.IllegalArgumentError as error:
+    except neuromation.api.errors.IllegalArgumentError as error:
         LOG_ERROR(f"Illegal argument(s) ({error})")
         sys.exit(EX_DATAERR)
 
-    except neuromation.api.ResourceNotFound as error:
+    except neuromation.api.errors.ResourceNotFound as error:
         LOG_ERROR(f"{error}")
         sys.exit(EX_OSFILE)
 
-    except neuromation.api.AuthenticationError as error:
+    except neuromation.api.errors.AuthenticationError as error:
         LOG_ERROR(f"Cannot authenticate ({error})")
         sys.exit(EX_NOPERM)
-    except neuromation.api.AuthorizationError as error:
+    except neuromation.api.errors.AuthorizationError as error:
         LOG_ERROR(f"Not enough permissions ({error})")
         sys.exit(EX_NOPERM)
 
-    except neuromation.api.ClientError as error:
+    except neuromation.api.errors.ClientError as error:
         LOG_ERROR(f"Application error ({error})")
         sys.exit(EX_SOFTWARE)
 
-    except neuromation.api.ServerNotAvailable as error:
+    except neuromation.api.errors.ServerNotAvailable as error:
         LOG_ERROR(f"Application error ({error})")
         sys.exit(EX_PLATFORMERROR)
 
