@@ -18,7 +18,6 @@ from neuromation.api import (
     RemoteImage,
     ResourceNotFound,
     Resources,
-    SecretFile,
     Volume,
 )
 from neuromation.api.jobs import (
@@ -26,6 +25,7 @@ from neuromation.api.jobs import (
     _calc_status,
     _job_description_from_api,
 )
+from neuromation.api.parser import SecretFile
 from neuromation.api.server_cfg import Preset
 from tests import _TestServerFactory
 
@@ -935,7 +935,9 @@ async def test_job_run_with_tags(
             http=HTTPPort(8181),
         )
         ret = await client.jobs.run(
-            container, is_preemptible=False, tags=["t1", "t2", "t3"],
+            container,
+            is_preemptible=False,
+            tags=["t1", "t2", "t3"],
         )
 
         assert ret == _job_description_from_api(JSON, client.parse)
@@ -1103,7 +1105,11 @@ async def test_job_run_with_relative_volume_uris(
         resources = Resources(16384, 7, 1, "test-gpu-model", True, None, None)
         volumes: List[Volume] = [
             Volume(URL("storage:path"), "/container/my_path", False),
-            Volume(URL("storage:/otheruser/path"), "/container/other_user_path", True,),
+            Volume(
+                URL("storage:/otheruser/path"),
+                "/container/other_user_path",
+                True,
+            ),
             Volume(
                 URL("storage://othercluster/otheruser/path"),
                 "/container/other_cluster_path",
@@ -1555,6 +1561,29 @@ def create_job_response(
     return result
 
 
+async def test_list_error_in_stream_response(
+    aiohttp_server: _TestServerFactory, make_client: _MakeClient
+) -> None:
+    error_result = {"error": "Failed"}
+
+    async def handler(request: web.Request) -> web.StreamResponse:
+        resp = web.StreamResponse()
+        resp.headers["Content-Type"] = "application/x-ndjson"
+        await resp.prepare(request)
+        await resp.write(json.dumps(error_result).encode() + b"\n")
+        return resp
+
+    app = web.Application()
+    app.router.add_get("/jobs", handler)
+    srv = await aiohttp_server(app)
+
+    async with make_client(srv.make_url("/")) as client:
+        with pytest.raises(Exception) as err:
+            async for _ in client.jobs.list():
+                pass
+        assert err.value.args[0] == "Failed"
+
+
 async def test_list_no_filter(
     aiohttp_server: _TestServerFactory, make_client: _MakeClient
 ) -> None:
@@ -1636,6 +1665,7 @@ async def test_list_filter_by_statuses(
         create_job_response("job-id-8", "pending"),
         create_job_response("job-id-9", "succeeded"),
         create_job_response("job-id-10", "failed"),
+        create_job_response("job-id-10", "cancelled"),
     ]
 
     async def handler(request: web.Request) -> web.Response:
@@ -1649,7 +1679,7 @@ async def test_list_filter_by_statuses(
     app.router.add_get("/jobs", handler)
     srv = await aiohttp_server(app)
 
-    statuses = {JobStatus.FAILED, JobStatus.SUCCEEDED}
+    statuses = {JobStatus.FAILED, JobStatus.SUCCEEDED, JobStatus.CANCELLED}
     async with make_client(srv.make_url("/")) as client:
         ret = [job async for job in client.jobs.list(statuses=statuses)]
 
