@@ -316,9 +316,13 @@ def test_e2e_multiple_env(helper: Helper) -> None:
 
 @pytest.mark.e2e
 def test_e2e_multiple_env_from_file(helper: Helper, tmp_path: Path) -> None:
-    env_file = tmp_path / "env_file"
-    env_file.write_text("VAR2=LAV2\nVAR3=VAL3\n")
-    bash_script = 'echo begin"$VAR""$VAR2""$VAR3"end  | grep beginVALVAL2VAL3end'
+    env_file1 = tmp_path / "env_file1"
+    env_file1.write_text("VAR2=LAV2\nVAR3=VAL3\n#VAR3=LAV3\nVAR4=LAV4\n\n")
+    env_file2 = tmp_path / "env_file2"
+    env_file2.write_text("VAR4=LAV4\nVAR4=VAL4")
+    bash_script = (
+        'echo begin"$VAR""$VAR2""$VAR3""$VAR4"end  | grep beginVALVAL2VAL3VAL4end'
+    )
     command = f"bash -c '{bash_script}'"
     captured = helper.run_cli(
         [
@@ -328,9 +332,13 @@ def test_e2e_multiple_env_from_file(helper: Helper, tmp_path: Path) -> None:
             "-e",
             "VAR=VAL",
             "-e",
+            "VAR2=VAL",
+            "-e",
             "VAR2=VAL2",
             "--env-file",
-            str(env_file),
+            str(env_file1),
+            "--env-file",
+            str(env_file2),
             "--no-wait-start",
             UBUNTU_IMAGE_NAME,
             command,
@@ -523,7 +531,7 @@ def test_job_save(helper: Helper, docker: aiodocker.Docker) -> None:
 
     # wait to free the job name:
     helper.run_cli(["job", "kill", job_id_1])
-    helper.wait_job_change_state_to(job_id_1, JobStatus.SUCCEEDED)
+    helper.wait_job_change_state_to(job_id_1, JobStatus.CANCELLED)
 
     command = 'sh -c \'[ "$(cat /test)" = "123" ]\''
     helper.run_job_and_wait_state(
@@ -821,24 +829,8 @@ def test_job_run_volume_all(helper: Helper) -> None:
     img = UBUNTU_IMAGE_NAME
 
     with pytest.raises(subprocess.CalledProcessError) as cm:
-        # first, run without --volume=ALL
-        captured = helper.run_cli(["--quiet", "run", "-T", img, command])
-    assert cm.value.returncode == 1
-
-    # then, run with --volume=ALL
-    captured = helper.run_cli(["run", "-T", "--volume=ALL", img, command])
-    msg = (
-        "Storage mountpoints will be available as the environment variables:\n"
-        f"  NEUROMATION_ROOT={root_mountpoint}\n"
-        f"  NEUROMATION_HOME={root_mountpoint}/{helper.username}"
-    )
-    assert msg in captured.out
-    found_job_ids = re.findall("Job ID: (job-.+)", captured.out)
-    assert len(found_job_ids) == 1
-    job_id = found_job_ids[0]
-    helper.wait_job_change_state_to(
-        job_id, JobStatus.SUCCEEDED, stop_state=JobStatus.FAILED
-    )
+        helper.run_cli(["run", "-T", "--volume=ALL", img, command])
+    assert cm.value.returncode == 127
 
 
 @pytest.mark.e2e
@@ -962,7 +954,9 @@ def test_job_autocomplete(helper: Helper) -> None:
 
     job_name = f"test-job-{os.urandom(5).hex()}"
     helper.kill_job(job_name)
-    job_id = helper.run_job_and_wait_state(ALPINE_IMAGE_NAME, "sleep 60", name=job_name)
+    job_id = helper.run_job_and_wait_state(
+        ALPINE_IMAGE_NAME, "sleep 600", name=job_name
+    )
 
     out = helper.autocomplete(["kill", "test-job"])
     assert job_name in out
